"""Generated model names for requesty provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 320
"""

from __future__ import annotations

from typing import Literal


RequestyModels = Literal[
    "requesty:alibaba/qwen-max",
    "requesty:alibaba/qwen-plus",
    "requesty:alibaba/qwen-turbo",
    "requesty:alibaba/qwen3-30b-a3b-instruct-2507",
    "requesty:alibaba/qwen3-coder-flash",
    "requesty:alibaba/qwen3-coder-plus",
    "requesty:alibaba/qwen3-max",
    "requesty:anthropic/claude-3-5-haiku",
    "requesty:anthropic/claude-3-7-sonnet",
    "requesty:anthropic/claude-3-haiku",
    "requesty:anthropic/claude-3-opus",
    "requesty:anthropic/claude-haiku-4-5",
    "requesty:anthropic/claude-opus-4",
    "requesty:anthropic/claude-opus-4-1",
    "requesty:anthropic/claude-sonnet-4",
    "requesty:anthropic/claude-sonnet-4-5",
    "requesty:azure/gpt-4.1",
    "requesty:azure/gpt-4.1-mini",
    "requesty:azure/gpt-4.1-mini@eastus2",
    "requesty:azure/gpt-4.1-mini@francecentral",
    "requesty:azure/gpt-4.1-mini@swedencentral",
    "requesty:azure/gpt-4.1-mini@uksouth",
    "requesty:azure/gpt-4.1-mini@westus3",
    "requesty:azure/gpt-4.1-nano",
    "requesty:azure/gpt-4.1-nano@eastus2",
    "requesty:azure/gpt-4.1-nano@francecentral",
    "requesty:azure/gpt-4.1-nano@swedencentral",
    "requesty:azure/gpt-4.1-nano@uksouth",
    "requesty:azure/gpt-4.1-nano@westus3",
    "requesty:azure/gpt-4.1@eastus2",
    "requesty:azure/gpt-4.1@francecentral",
    "requesty:azure/gpt-4.1@swedencentral",
    "requesty:azure/gpt-4.1@uksouth",
    "requesty:azure/gpt-4.1@westus3",
    "requesty:azure/gpt-5",
    "requesty:azure/gpt-5-mini",
    "requesty:azure/gpt-5-mini@eastus2",
    "requesty:azure/gpt-5-mini@swedencentral",
    "requesty:azure/gpt-5-mini@uksouth",
    "requesty:azure/gpt-5-nano",
    "requesty:azure/gpt-5-nano@eastus2",
    "requesty:azure/gpt-5-nano@swedencentral",
    "requesty:azure/gpt-5@eastus2",
    "requesty:azure/gpt-5@swedencentral",
    "requesty:azure/gpt-5@uksouth",
    "requesty:azure/o4-mini",
    "requesty:azure/o4-mini@eastus2",
    "requesty:azure/o4-mini@francecentral",
    "requesty:azure/o4-mini@swedencentral",
    "requesty:azure/o4-mini@uksouth",
    "requesty:azure/o4-mini@westus3",
    "requesty:bedrock/claude-3-7-sonnet",
    "requesty:bedrock/claude-3-7-sonnet@eu-central-1",
    "requesty:bedrock/claude-3-7-sonnet@eu-north-1",
    "requesty:bedrock/claude-3-7-sonnet@eu-west-1",
    "requesty:bedrock/claude-3-7-sonnet@eu-west-3",
    "requesty:bedrock/claude-3-7-sonnet@us-east-1",
    "requesty:bedrock/claude-3-7-sonnet@us-east-2",
    "requesty:bedrock/claude-3-7-sonnet@us-west-2",
    "requesty:bedrock/claude-haiku-4-5",
    "requesty:bedrock/claude-haiku-4-5@eu-central-1",
    "requesty:bedrock/claude-haiku-4-5@eu-north-1",
    "requesty:bedrock/claude-haiku-4-5@eu-west-1",
    "requesty:bedrock/claude-haiku-4-5@eu-west-3",
    "requesty:bedrock/claude-haiku-4-5@us-east-1",
    "requesty:bedrock/claude-haiku-4-5@us-east-2",
    "requesty:bedrock/claude-haiku-4-5@us-west-2",
    "requesty:bedrock/claude-opus-4",
    "requesty:bedrock/claude-opus-4@us-east-1",
    "requesty:bedrock/claude-opus-4@us-east-2",
    "requesty:bedrock/claude-opus-4@us-west-2",
    "requesty:bedrock/claude-sonnet-4",
    "requesty:bedrock/claude-sonnet-4-5",
    "requesty:bedrock/claude-sonnet-4-5@eu-central-1",
    "requesty:bedrock/claude-sonnet-4-5@eu-north-1",
    "requesty:bedrock/claude-sonnet-4-5@eu-west-1",
    "requesty:bedrock/claude-sonnet-4-5@eu-west-3",
    "requesty:bedrock/claude-sonnet-4-5@us-east-1",
    "requesty:bedrock/claude-sonnet-4-5@us-east-2",
    "requesty:bedrock/claude-sonnet-4-5@us-west-2",
    "requesty:bedrock/claude-sonnet-4@eu-central-1",
    "requesty:bedrock/claude-sonnet-4@eu-north-1",
    "requesty:bedrock/claude-sonnet-4@eu-west-1",
    "requesty:bedrock/claude-sonnet-4@eu-west-3",
    "requesty:bedrock/claude-sonnet-4@us-east-1",
    "requesty:bedrock/claude-sonnet-4@us-east-2",
    "requesty:bedrock/claude-sonnet-4@us-west-2",
    "requesty:coding/claude-3-7-sonnet-20250219",
    "requesty:coding/claude-3-7-sonnet-20250219:1024",
    "requesty:coding/claude-3-7-sonnet-20250219:16384",
    "requesty:coding/claude-3-7-sonnet-20250219:64000",
    "requesty:coding/claude-3-7-sonnet-20250219:8192",
    "requesty:coding/claude-3-7-sonnet-20250219:high",
    "requesty:coding/claude-3-7-sonnet-20250219:low",
    "requesty:coding/claude-3-7-sonnet-20250219:max",
    "requesty:coding/claude-3-7-sonnet-20250219:medium",
    "requesty:coding/claude-opus-4-20250514",
    "requesty:coding/claude-sonnet-4-20250514",
    "requesty:coding/gemini-2.5-flash",
    "requesty:coding/gemini-2.5-flash@europe-central2",
    "requesty:coding/gemini-2.5-flash@europe-north1",
    "requesty:coding/gemini-2.5-flash@europe-west1",
    "requesty:coding/gemini-2.5-flash@europe-west4",
    "requesty:coding/gemini-2.5-flash@europe-west8",
    "requesty:coding/gemini-2.5-flash@us-central1",
    "requesty:coding/gemini-2.5-flash@us-east1",
    "requesty:coding/gemini-2.5-flash@us-east5",
    "requesty:coding/gemini-2.5-flash@us-south1",
    "requesty:coding/gemini-2.5-flash@us-west1",
    "requesty:coding/gemini-2.5-pro",
    "requesty:coding/gemini-2.5-pro@europe-central2",
    "requesty:coding/gemini-2.5-pro@europe-north1",
    "requesty:coding/gemini-2.5-pro@europe-west1",
    "requesty:coding/gemini-2.5-pro@europe-west4",
    "requesty:coding/gemini-2.5-pro@europe-west8",
    "requesty:coding/gemini-2.5-pro@us-central1",
    "requesty:coding/gemini-2.5-pro@us-east1",
    "requesty:coding/gemini-2.5-pro@us-east5",
    "requesty:coding/gemini-2.5-pro@us-south1",
    "requesty:coding/gemini-2.5-pro@us-west1",
    "requesty:deepinfra/Qwen/Qwen2.5-72B-Instruct",
    "requesty:deepinfra/Qwen/Qwen2.5-Coder-32B-Instruct",
    "requesty:deepinfra/Qwen/Qwen3-235B-A22B",
    "requesty:deepinfra/Qwen/Qwen3-32B",
    "requesty:deepinfra/Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "requesty:deepinfra/deepseek-ai/DeepSeek-R1",
    "requesty:deepinfra/deepseek-ai/DeepSeek-R1-Distill-Llama-70B",
    "requesty:deepinfra/deepseek-ai/DeepSeek-V3",
    "requesty:deepinfra/deepseek-ai/DeepSeek-V3.1",
    "requesty:deepinfra/meta-llama/Llama-3.2-90B-Vision-Instruct",
    "requesty:deepinfra/meta-llama/Llama-3.3-70B-Instruct",
    "requesty:deepinfra/meta-llama/Llama-3.3-70B-Instruct-Turbo",
    "requesty:deepinfra/meta-llama/Meta-Llama-3.1-405B-Instruct",
    "requesty:deepinfra/meta-llama/Meta-Llama-3.1-70B-Instruct",
    "requesty:deepinfra/meta-llama/Meta-Llama-3.1-8B-Instruct-Turbo",
    "requesty:deepinfra/microsoft/phi-4",
    "requesty:deepinfra/zai-org/GLM-4.5",
    "requesty:deepinfra/zai-org/GLM-4.5-Air",
    "requesty:deepseek/deepseek-chat",
    "requesty:deepseek/deepseek-reasoner",
    "requesty:google/gemini-2.0-flash-001",
    "requesty:google/gemini-2.5-flash",
    "requesty:google/gemini-2.5-flash-lite-preview-06-17",
    "requesty:google/gemini-2.5-pro",
    "requesty:groq/moonshotai/Kimi-K2-Instruct-0905",
    "requesty:groq/moonshotai/kimi-k2-instruct",
    "requesty:groq/openai/gpt-oss-120b",
    "requesty:groq/openai/gpt-oss-20b",
    "requesty:minimaxi/MiniMax-M2",
    "requesty:mistral/codestral-latest",
    "requesty:mistral/devstral-medium-2507",
    "requesty:mistral/devstral-small-2507",
    "requesty:mistral/devstral-small-latest",
    "requesty:mistral/mistral-large-latest",
    "requesty:mistral/mistral-medium-latest",
    "requesty:mistral/mistral-small-latest",
    "requesty:mistral/open-mistral-7b",
    "requesty:mistral/pixtral-large-latest",
    "requesty:moonshot/kimi-k2-0711-preview",
    "requesty:moonshot/kimi-k2-turbo-preview",
    "requesty:nebius/Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "requesty:nebius/deepseek-ai/DeepSeek-R1-0528",
    "requesty:nebius/deepseek-ai/DeepSeek-V3-0324",
    "requesty:nebius/deepseek-ai/DeepSeek-V3-0324-fast",
    "requesty:nebius/meta-llama/Llama-3.3-70B-Instruct",
    "requesty:nebius/moonshotai/Kimi-K2-Instruct",
    "requesty:nebius/zai-org/GLM-4.5",
    "requesty:novita/Sao10K/L3-8B-Stheno-v3.2",
    "requesty:novita/deepseek/deepseek-prover-v2-671b",
    "requesty:novita/deepseek/deepseek-r1",
    "requesty:novita/deepseek/deepseek-r1-distill-llama-70b",
    "requesty:novita/deepseek/deepseek-r1-distill-qwen-14b",
    "requesty:novita/deepseek/deepseek-r1-distill-qwen-32b",
    "requesty:novita/deepseek/deepseek-r1-turbo",
    "requesty:novita/deepseek/deepseek-v3-0324",
    "requesty:novita/deepseek/deepseek-v3-turbo",
    "requesty:novita/deepseek/deepseek_v3",
    "requesty:novita/gryphe/mythomax-l2-13b",
    "requesty:novita/meta-llama/llama-3-70b-instruct",
    "requesty:novita/meta-llama/llama-3-8b-instruct",
    "requesty:novita/meta-llama/llama-3.1-8b-instruct",
    "requesty:novita/meta-llama/llama-3.2-1b-instruct",
    "requesty:novita/meta-llama/llama-3.2-3b-instruct",
    "requesty:novita/meta-llama/llama-3.3-70b-instruct",
    "requesty:novita/meta-llama/llama-4-maverick-17b-128e-instruct-fp8",
    "requesty:novita/microsoft/wizardlm-2-8x22b",
    "requesty:novita/mistralai/mistral-nemo",
    "requesty:novita/moonshotai/kimi-k2-instruct",
    "requesty:novita/nousresearch/hermes-2-pro-llama-3-8b",
    "requesty:novita/qwen/qwen-2.5-72b-instruct",
    "requesty:novita/qwen/qwen2.5-vl-72b-instruct",
    "requesty:novita/qwen/qwen3-235b-a22b-fp8",
    "requesty:novita/sao10k/l3-70b-euryale-v2.1",
    "requesty:novita/sao10k/l3-8b-lunaris",
    "requesty:novita/sao10k/l31-70b-euryale-v2.2",
    "requesty:novita/zai-org/glm-4.5",
    "requesty:novita/zai-org/glm-4.6",
    "requesty:openai-responses/gpt-5-codex",
    "requesty:openai-responses/gpt-5-mini",
    "requesty:openai-responses/gpt-5-nano",
    "requesty:openai-responses/gpt-5-pro",
    "requesty:openai-responses/o3-mini",
    "requesty:openai-responses/o3-pro",
    "requesty:openai-responses/o4-mini",
    "requesty:openai/chatgpt-4o",
    "requesty:openai/gpt-4.1",
    "requesty:openai/gpt-4.1-mini",
    "requesty:openai/gpt-4.1-nano",
    "requesty:openai/gpt-4o",
    "requesty:openai/gpt-4o-2024-05-13",
    "requesty:openai/gpt-4o-2024-08-06",
    "requesty:openai/gpt-4o-2024-11-20",
    "requesty:openai/gpt-4o-mini",
    "requesty:openai/gpt-5",
    "requesty:openai/gpt-5-chat",
    "requesty:openai/gpt-5-mini",
    "requesty:openai/gpt-5-mini:flex",
    "requesty:openai/gpt-5-mini:priority",
    "requesty:openai/gpt-5-nano",
    "requesty:openai/gpt-5-nano:flex",
    "requesty:openai/gpt-5.1",
    "requesty:openai/gpt-5:flex",
    "requesty:openai/gpt-5:priority",
    "requesty:openai/o1",
    "requesty:openai/o1-pro",
    "requesty:openai/o1:high",
    "requesty:openai/o1:low",
    "requesty:openai/o1:medium",
    "requesty:openai/o3",
    "requesty:openai/o3-deep-research",
    "requesty:openai/o3-mini",
    "requesty:openai/o3-mini:high",
    "requesty:openai/o3-mini:low",
    "requesty:openai/o3-mini:medium",
    "requesty:openai/o3:flex",
    "requesty:openai/o4-mini",
    "requesty:openai/o4-mini-deep-research",
    "requesty:openai/o4-mini:flex",
    "requesty:openai/o4-mini:high",
    "requesty:openai/o4-mini:low",
    "requesty:openai/o4-mini:medium",
    "requesty:parasail/parasail-deepseek-r1",
    "requesty:parasail/parasail-deepseek-v3-0324",
    "requesty:parasail/parasail-gemma3-27b-it",
    "requesty:parasail/parasail-glm-45",
    "requesty:parasail/parasail-kimi-k2-instruct",
    "requesty:parasail/parasail-qwen25-vl-72b-instruct",
    "requesty:parasail/parasail-qwen3-235b-a22b-instruct-2507",
    "requesty:perplexity/sonar",
    "requesty:perplexity/sonar-pro",
    "requesty:perplexity/sonar-reasoning-pro",
    "requesty:smart/task",
    "requesty:together/Qwen/QwQ-32B-Preview",
    "requesty:together/Qwen/Qwen2.5-72B-Instruct-Turbo",
    "requesty:together/Qwen/Qwen2.5-7B-Instruct-Turbo",
    "requesty:together/Qwen/Qwen2.5-Coder-32B-Instruct",
    "requesty:together/deepseek-ai/DeepSeek-R1",
    "requesty:together/deepseek-ai/DeepSeek-V3",
    "requesty:together/meta-llama/Llama-3-70b-chat-hf",
    "requesty:together/meta-llama/Llama-3.2-3B-Instruct-Turbo",
    "requesty:together/meta-llama/Llama-3.3-70B-Instruct-Turbo",
    "requesty:together/meta-llama/LlamaGuard-2-8b",
    "requesty:together/meta-llama/Meta-Llama-3-70B-Instruct-Turbo",
    "requesty:together/meta-llama/Meta-Llama-3-8B-Instruct-Lite",
    "requesty:together/meta-llama/Meta-Llama-3.1-70B-Instruct-Turbo",
    "requesty:together/meta-llama/Meta-Llama-3.1-8B-Instruct-Turbo",
    "requesty:together/meta-llama/Meta-Llama-Guard-3-8B",
    "requesty:vertex/claude-3-5-sonnet",
    "requesty:vertex/claude-3-5-sonnet@europe-west1",
    "requesty:vertex/claude-3-5-sonnet@us-east5",
    "requesty:vertex/claude-3-7-sonnet",
    "requesty:vertex/claude-3-7-sonnet@europe-west1",
    "requesty:vertex/claude-3-7-sonnet@us-east5",
    "requesty:vertex/claude-haiku-4-5",
    "requesty:vertex/claude-haiku-4-5@europe-west1",
    "requesty:vertex/claude-haiku-4-5@us-east5",
    "requesty:vertex/claude-opus-4",
    "requesty:vertex/claude-opus-4-1",
    "requesty:vertex/claude-opus-4-1@us-east5",
    "requesty:vertex/claude-opus-4@us-east5",
    "requesty:vertex/claude-sonnet-4",
    "requesty:vertex/claude-sonnet-4-5",
    "requesty:vertex/claude-sonnet-4-5@europe-west1",
    "requesty:vertex/claude-sonnet-4-5@us-east5",
    "requesty:vertex/claude-sonnet-4@europe-west1",
    "requesty:vertex/claude-sonnet-4@us-east5",
    "requesty:vertex/google/gemini-2.5-flash",
    "requesty:vertex/google/gemini-2.5-flash-image-preview",
    "requesty:vertex/google/gemini-2.5-flash@europe-central2",
    "requesty:vertex/google/gemini-2.5-flash@europe-north1",
    "requesty:vertex/google/gemini-2.5-flash@europe-west1",
    "requesty:vertex/google/gemini-2.5-flash@europe-west4",
    "requesty:vertex/google/gemini-2.5-flash@europe-west8",
    "requesty:vertex/google/gemini-2.5-flash@us-central1",
    "requesty:vertex/google/gemini-2.5-flash@us-east1",
    "requesty:vertex/google/gemini-2.5-flash@us-east5",
    "requesty:vertex/google/gemini-2.5-flash@us-south1",
    "requesty:vertex/google/gemini-2.5-flash@us-west1",
    "requesty:vertex/google/gemini-2.5-pro",
    "requesty:vertex/google/gemini-2.5-pro@europe-central2",
    "requesty:vertex/google/gemini-2.5-pro@europe-north1",
    "requesty:vertex/google/gemini-2.5-pro@europe-west1",
    "requesty:vertex/google/gemini-2.5-pro@europe-west4",
    "requesty:vertex/google/gemini-2.5-pro@europe-west8",
    "requesty:vertex/google/gemini-2.5-pro@us-central1",
    "requesty:vertex/google/gemini-2.5-pro@us-east1",
    "requesty:vertex/google/gemini-2.5-pro@us-east5",
    "requesty:vertex/google/gemini-2.5-pro@us-south1",
    "requesty:vertex/google/gemini-2.5-pro@us-west1",
    "requesty:xai/grok-2-1212",
    "requesty:xai/grok-3",
    "requesty:xai/grok-3-mini",
    "requesty:xai/grok-3-mini:high",
    "requesty:xai/grok-3-mini:low",
    "requesty:xai/grok-4",
    "requesty:xai/grok-4-fast",
    "requesty:xai/grok-4-fast-non-reasoning",
    "requesty:xai/grok-code-fast-1",
    "requesty:zai/GLM-4.5",
    "requesty:zai/GLM-4.6",
]

__all__ = ["RequestyModels"]
