"""Generated model names for vercel-gateway provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 125
"""

from __future__ import annotations

from typing import Literal


Vercel_GatewayModels = Literal[
    "vercel-gateway:alibaba/qwen-3-14b",
    "vercel-gateway:alibaba/qwen-3-235b",
    "vercel-gateway:alibaba/qwen-3-30b",
    "vercel-gateway:alibaba/qwen-3-32b",
    "vercel-gateway:alibaba/qwen3-coder",
    "vercel-gateway:alibaba/qwen3-coder-30b-a3b",
    "vercel-gateway:alibaba/qwen3-coder-plus",
    "vercel-gateway:alibaba/qwen3-max",
    "vercel-gateway:alibaba/qwen3-max-preview",
    "vercel-gateway:alibaba/qwen3-next-80b-a3b-instruct",
    "vercel-gateway:alibaba/qwen3-next-80b-a3b-thinking",
    "vercel-gateway:alibaba/qwen3-vl-instruct",
    "vercel-gateway:alibaba/qwen3-vl-thinking",
    "vercel-gateway:amazon/nova-lite",
    "vercel-gateway:amazon/nova-micro",
    "vercel-gateway:amazon/nova-pro",
    "vercel-gateway:anthropic/claude-3-haiku",
    "vercel-gateway:anthropic/claude-3-opus",
    "vercel-gateway:anthropic/claude-3.5-haiku",
    "vercel-gateway:anthropic/claude-3.5-sonnet",
    "vercel-gateway:anthropic/claude-3.5-sonnet-20240620",
    "vercel-gateway:anthropic/claude-3.7-sonnet",
    "vercel-gateway:anthropic/claude-haiku-4.5",
    "vercel-gateway:anthropic/claude-opus-4",
    "vercel-gateway:anthropic/claude-opus-4.1",
    "vercel-gateway:anthropic/claude-sonnet-4",
    "vercel-gateway:anthropic/claude-sonnet-4.5",
    "vercel-gateway:cohere/command-a",
    "vercel-gateway:deepseek/deepseek-r1",
    "vercel-gateway:deepseek/deepseek-v3",
    "vercel-gateway:deepseek/deepseek-v3.1",
    "vercel-gateway:deepseek/deepseek-v3.1-terminus",
    "vercel-gateway:deepseek/deepseek-v3.2-exp",
    "vercel-gateway:deepseek/deepseek-v3.2-exp-thinking",
    "vercel-gateway:google/gemini-2.0-flash",
    "vercel-gateway:google/gemini-2.0-flash-lite",
    "vercel-gateway:google/gemini-2.5-flash",
    "vercel-gateway:google/gemini-2.5-flash-image",
    "vercel-gateway:google/gemini-2.5-flash-image-preview",
    "vercel-gateway:google/gemini-2.5-flash-lite",
    "vercel-gateway:google/gemini-2.5-flash-lite-preview-09-2025",
    "vercel-gateway:google/gemini-2.5-flash-preview-09-2025",
    "vercel-gateway:google/gemini-2.5-pro",
    "vercel-gateway:inception/mercury-coder-small",
    "vercel-gateway:meituan/longcat-flash-chat",
    "vercel-gateway:meituan/longcat-flash-thinking",
    "vercel-gateway:meta/llama-3.1-70b",
    "vercel-gateway:meta/llama-3.1-8b",
    "vercel-gateway:meta/llama-3.2-11b",
    "vercel-gateway:meta/llama-3.2-1b",
    "vercel-gateway:meta/llama-3.2-3b",
    "vercel-gateway:meta/llama-3.2-90b",
    "vercel-gateway:meta/llama-3.3-70b",
    "vercel-gateway:meta/llama-4-maverick",
    "vercel-gateway:meta/llama-4-scout",
    "vercel-gateway:minimax/minimax-m2",
    "vercel-gateway:mistral/codestral",
    "vercel-gateway:mistral/devstral-small",
    "vercel-gateway:mistral/magistral-medium",
    "vercel-gateway:mistral/magistral-medium-2506",
    "vercel-gateway:mistral/magistral-small",
    "vercel-gateway:mistral/magistral-small-2506",
    "vercel-gateway:mistral/ministral-3b",
    "vercel-gateway:mistral/ministral-8b",
    "vercel-gateway:mistral/mistral-large",
    "vercel-gateway:mistral/mistral-medium",
    "vercel-gateway:mistral/mistral-small",
    "vercel-gateway:mistral/mixtral-8x22b-instruct",
    "vercel-gateway:mistral/pixtral-12b",
    "vercel-gateway:mistral/pixtral-large",
    "vercel-gateway:moonshotai/kimi-k2",
    "vercel-gateway:moonshotai/kimi-k2-0905",
    "vercel-gateway:moonshotai/kimi-k2-thinking",
    "vercel-gateway:moonshotai/kimi-k2-thinking-turbo",
    "vercel-gateway:moonshotai/kimi-k2-turbo",
    "vercel-gateway:morph/morph-v3-fast",
    "vercel-gateway:morph/morph-v3-large",
    "vercel-gateway:openai/gpt-3.5-turbo",
    "vercel-gateway:openai/gpt-3.5-turbo-instruct",
    "vercel-gateway:openai/gpt-4-turbo",
    "vercel-gateway:openai/gpt-4.1",
    "vercel-gateway:openai/gpt-4.1-mini",
    "vercel-gateway:openai/gpt-4.1-nano",
    "vercel-gateway:openai/gpt-4o",
    "vercel-gateway:openai/gpt-4o-mini",
    "vercel-gateway:openai/gpt-5",
    "vercel-gateway:openai/gpt-5-chat",
    "vercel-gateway:openai/gpt-5-codex",
    "vercel-gateway:openai/gpt-5-mini",
    "vercel-gateway:openai/gpt-5-nano",
    "vercel-gateway:openai/gpt-5-pro",
    "vercel-gateway:openai/gpt-5.1-codex",
    "vercel-gateway:openai/gpt-5.1-codex-mini",
    "vercel-gateway:openai/gpt-5.1-instant",
    "vercel-gateway:openai/gpt-5.1-thinking",
    "vercel-gateway:openai/gpt-oss-120b",
    "vercel-gateway:openai/gpt-oss-20b",
    "vercel-gateway:openai/gpt-oss-safeguard-20b",
    "vercel-gateway:openai/o1",
    "vercel-gateway:openai/o3",
    "vercel-gateway:openai/o3-deep-research",
    "vercel-gateway:openai/o3-mini",
    "vercel-gateway:openai/o4-mini",
    "vercel-gateway:perplexity/sonar",
    "vercel-gateway:perplexity/sonar-pro",
    "vercel-gateway:perplexity/sonar-reasoning",
    "vercel-gateway:perplexity/sonar-reasoning-pro",
    "vercel-gateway:stealth/sonoma-dusk-alpha",
    "vercel-gateway:stealth/sonoma-sky-alpha",
    "vercel-gateway:vercel/v0-1.0-md",
    "vercel-gateway:vercel/v0-1.5-md",
    "vercel-gateway:xai/grok-2",
    "vercel-gateway:xai/grok-2-vision",
    "vercel-gateway:xai/grok-3",
    "vercel-gateway:xai/grok-3-fast",
    "vercel-gateway:xai/grok-3-mini",
    "vercel-gateway:xai/grok-3-mini-fast",
    "vercel-gateway:xai/grok-4",
    "vercel-gateway:xai/grok-4-fast-non-reasoning",
    "vercel-gateway:xai/grok-4-fast-reasoning",
    "vercel-gateway:xai/grok-code-fast-1",
    "vercel-gateway:zai/glm-4.5",
    "vercel-gateway:zai/glm-4.5-air",
    "vercel-gateway:zai/glm-4.5v",
    "vercel-gateway:zai/glm-4.6",
]

__all__ = ["Vercel_GatewayModels"]
