"""Generated model names for deepseek provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 2
"""

from __future__ import annotations

from typing import Literal


DeepseekModels = Literal[
    "deepseek:deepseek-chat",
    "deepseek:deepseek-reasoner",
]

__all__ = ["DeepseekModels"]
