"""Generated model names for moonshotai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 5
"""

from __future__ import annotations

from typing import Literal


MoonshotaiModels = Literal[
    "moonshotai:kimi-k2-0711-preview",
    "moonshotai:kimi-k2-0905-preview",
    "moonshotai:kimi-k2-thinking",
    "moonshotai:kimi-k2-thinking-turbo",
    "moonshotai:kimi-k2-turbo-preview",
]

__all__ = ["MoonshotaiModels"]
