"""Generated model names for anthropic provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 19
"""

from __future__ import annotations

from typing import Literal


AnthropicModels = Literal[
    "anthropic:claude-3-5-haiku-20241022",
    "anthropic:claude-3-5-haiku-latest",
    "anthropic:claude-3-5-sonnet-20240620",
    "anthropic:claude-3-5-sonnet-20241022",
    "anthropic:claude-3-7-sonnet-20250219",
    "anthropic:claude-3-7-sonnet-latest",
    "anthropic:claude-3-haiku-20240307",
    "anthropic:claude-3-opus-20240229",
    "anthropic:claude-3-sonnet-20240229",
    "anthropic:claude-haiku-4-5",
    "anthropic:claude-haiku-4-5-20251001",
    "anthropic:claude-opus-4-0",
    "anthropic:claude-opus-4-1",
    "anthropic:claude-opus-4-1-20250805",
    "anthropic:claude-opus-4-20250514",
    "anthropic:claude-sonnet-4-0",
    "anthropic:claude-sonnet-4-20250514",
    "anthropic:claude-sonnet-4-5",
    "anthropic:claude-sonnet-4-5-20250929",
]

__all__ = ["AnthropicModels"]
