"""Generated model names from all providers.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total providers: 15
"""

from __future__ import annotations


from .anthropic import AnthropicModels
from .cerebras import CerebrasModels
from .comet import CometModels
from .copilot import CopilotModels
from .deepseek import DeepseekModels
from .gemini import GeminiModels
from .groq import GroqModels
from .mistral import MistralModels
from .moonshotai import MoonshotaiModels
from .openai import OpenaiModels
from .openrouter import OpenrouterModels
from .requesty import RequestyModels
from .vercel_gateway import Vercel_GatewayModels
from .xai import XaiModels
from .zai import ZaiModels

# Union of all provider model types
ModelName = (
    AnthropicModels
    | CerebrasModels
    | CometModels
    | CopilotModels
    | DeepseekModels
    | GeminiModels
    | GroqModels
    | MistralModels
    | MoonshotaiModels
    | OpenaiModels
    | OpenrouterModels
    | RequestyModels
    | Vercel_GatewayModels
    | XaiModels
    | ZaiModels
)

__all__ = [
    "AnthropicModels",
    "CerebrasModels",
    "CometModels",
    "CopilotModels",
    "DeepseekModels",
    "GeminiModels",
    "GroqModels",
    "MistralModels",
    "ModelName",
    "MoonshotaiModels",
    "OpenaiModels",
    "OpenrouterModels",
    "RequestyModels",
    "Vercel_GatewayModels",
    "XaiModels",
    "ZaiModels",
]
