"""Generated model names for xai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 8
"""

from __future__ import annotations

from typing import Literal


XaiModels = Literal[
    "xai:grok-2-1212",
    "xai:grok-2-vision-1212",
    "xai:grok-3",
    "xai:grok-3-mini",
    "xai:grok-4-0709",
    "xai:grok-4-fast-non-reasoning",
    "xai:grok-4-fast-reasoning",
    "xai:grok-code-fast-1",
]

__all__ = ["XaiModels"]
