"""Generated model names for cerebras provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 4
"""

from __future__ import annotations

from typing import Literal


CerebrasModels = Literal[
    "cerebras:gpt-oss-120b",
    "cerebras:qwen-3-235b-a22b-instruct-2507",
    "cerebras:qwen-3-coder-480b",
    "cerebras:zai-glm-4.6",
]

__all__ = ["CerebrasModels"]
