"""Generated model names for openrouter provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 342
"""

from __future__ import annotations

from typing import Literal


OpenrouterModels = Literal[
    "openrouter:agentica-org/deepcoder-14b-preview",
    "openrouter:agentica-org/deepcoder-14b-preview:free",
    "openrouter:ai21/jamba-large-1.7",
    "openrouter:ai21/jamba-mini-1.7",
    "openrouter:aion-labs/aion-1.0",
    "openrouter:aion-labs/aion-1.0-mini",
    "openrouter:aion-labs/aion-rp-llama-3.1-8b",
    "openrouter:alfredpros/codellama-7b-instruct-solidity",
    "openrouter:alibaba/tongyi-deepresearch-30b-a3b",
    "openrouter:alibaba/tongyi-deepresearch-30b-a3b:free",
    "openrouter:allenai/olmo-2-0325-32b-instruct",
    "openrouter:alpindale/goliath-120b",
    "openrouter:amazon/nova-lite-v1",
    "openrouter:amazon/nova-micro-v1",
    "openrouter:amazon/nova-premier-v1",
    "openrouter:amazon/nova-pro-v1",
    "openrouter:anthracite-org/magnum-v4-72b",
    "openrouter:anthropic/claude-3-haiku",
    "openrouter:anthropic/claude-3-opus",
    "openrouter:anthropic/claude-3.5-haiku",
    "openrouter:anthropic/claude-3.5-haiku-20241022",
    "openrouter:anthropic/claude-3.5-sonnet",
    "openrouter:anthropic/claude-3.7-sonnet",
    "openrouter:anthropic/claude-3.7-sonnet:thinking",
    "openrouter:anthropic/claude-haiku-4.5",
    "openrouter:anthropic/claude-opus-4",
    "openrouter:anthropic/claude-opus-4.1",
    "openrouter:anthropic/claude-sonnet-4",
    "openrouter:anthropic/claude-sonnet-4.5",
    "openrouter:arcee-ai/afm-4.5b",
    "openrouter:arcee-ai/coder-large",
    "openrouter:arcee-ai/maestro-reasoning",
    "openrouter:arcee-ai/spotlight",
    "openrouter:arcee-ai/virtuoso-large",
    "openrouter:arliai/qwq-32b-arliai-rpr-v1",
    "openrouter:arliai/qwq-32b-arliai-rpr-v1:free",
    "openrouter:baidu/ernie-4.5-21b-a3b",
    "openrouter:baidu/ernie-4.5-21b-a3b-thinking",
    "openrouter:baidu/ernie-4.5-300b-a47b",
    "openrouter:baidu/ernie-4.5-vl-28b-a3b",
    "openrouter:baidu/ernie-4.5-vl-424b-a47b",
    "openrouter:bytedance/ui-tars-1.5-7b",
    "openrouter:cognitivecomputations/dolphin-mistral-24b-venice-edition:free",
    "openrouter:cohere/command-a",
    "openrouter:cohere/command-r-08-2024",
    "openrouter:cohere/command-r-plus-08-2024",
    "openrouter:cohere/command-r7b-12-2024",
    "openrouter:deepcogito/cogito-v2-preview-deepseek-671b",
    "openrouter:deepcogito/cogito-v2-preview-llama-109b-moe",
    "openrouter:deepcogito/cogito-v2-preview-llama-405b",
    "openrouter:deepcogito/cogito-v2-preview-llama-70b",
    "openrouter:deepseek/deepseek-chat",
    "openrouter:deepseek/deepseek-chat-v3-0324",
    "openrouter:deepseek/deepseek-chat-v3-0324:free",
    "openrouter:deepseek/deepseek-chat-v3.1",
    "openrouter:deepseek/deepseek-chat-v3.1:free",
    "openrouter:deepseek/deepseek-prover-v2",
    "openrouter:deepseek/deepseek-r1",
    "openrouter:deepseek/deepseek-r1-0528",
    "openrouter:deepseek/deepseek-r1-0528-qwen3-8b",
    "openrouter:deepseek/deepseek-r1-0528-qwen3-8b:free",
    "openrouter:deepseek/deepseek-r1-0528:free",
    "openrouter:deepseek/deepseek-r1-distill-llama-70b",
    "openrouter:deepseek/deepseek-r1-distill-llama-70b:free",
    "openrouter:deepseek/deepseek-r1-distill-qwen-14b",
    "openrouter:deepseek/deepseek-r1-distill-qwen-32b",
    "openrouter:deepseek/deepseek-r1:free",
    "openrouter:deepseek/deepseek-v3.1-terminus",
    "openrouter:deepseek/deepseek-v3.1-terminus:exacto",
    "openrouter:deepseek/deepseek-v3.2-exp",
    "openrouter:eleutherai/llemma_7b",
    "openrouter:google/gemini-2.0-flash-001",
    "openrouter:google/gemini-2.0-flash-exp:free",
    "openrouter:google/gemini-2.0-flash-lite-001",
    "openrouter:google/gemini-2.5-flash",
    "openrouter:google/gemini-2.5-flash-image",
    "openrouter:google/gemini-2.5-flash-image-preview",
    "openrouter:google/gemini-2.5-flash-lite",
    "openrouter:google/gemini-2.5-flash-lite-preview-06-17",
    "openrouter:google/gemini-2.5-flash-lite-preview-09-2025",
    "openrouter:google/gemini-2.5-flash-preview-09-2025",
    "openrouter:google/gemini-2.5-pro",
    "openrouter:google/gemini-2.5-pro-preview",
    "openrouter:google/gemini-2.5-pro-preview-05-06",
    "openrouter:google/gemma-2-27b-it",
    "openrouter:google/gemma-2-9b-it",
    "openrouter:google/gemma-3-12b-it",
    "openrouter:google/gemma-3-12b-it:free",
    "openrouter:google/gemma-3-27b-it",
    "openrouter:google/gemma-3-27b-it:free",
    "openrouter:google/gemma-3-4b-it",
    "openrouter:google/gemma-3-4b-it:free",
    "openrouter:google/gemma-3n-e2b-it:free",
    "openrouter:google/gemma-3n-e4b-it",
    "openrouter:google/gemma-3n-e4b-it:free",
    "openrouter:gryphe/mythomax-l2-13b",
    "openrouter:ibm-granite/granite-4.0-h-micro",
    "openrouter:inception/mercury",
    "openrouter:inception/mercury-coder",
    "openrouter:inclusionai/ling-1t",
    "openrouter:inclusionai/ring-1t",
    "openrouter:inflection/inflection-3-pi",
    "openrouter:inflection/inflection-3-productivity",
    "openrouter:kwaipilot/kat-coder-pro:free",
    "openrouter:liquid/lfm-2.2-6b",
    "openrouter:liquid/lfm2-8b-a1b",
    "openrouter:mancer/weaver",
    "openrouter:meituan/longcat-flash-chat",
    "openrouter:meituan/longcat-flash-chat:free",
    "openrouter:meta-llama/llama-3-70b-instruct",
    "openrouter:meta-llama/llama-3-8b-instruct",
    "openrouter:meta-llama/llama-3.1-405b",
    "openrouter:meta-llama/llama-3.1-405b-instruct",
    "openrouter:meta-llama/llama-3.1-70b-instruct",
    "openrouter:meta-llama/llama-3.1-8b-instruct",
    "openrouter:meta-llama/llama-3.2-11b-vision-instruct",
    "openrouter:meta-llama/llama-3.2-1b-instruct",
    "openrouter:meta-llama/llama-3.2-3b-instruct",
    "openrouter:meta-llama/llama-3.2-3b-instruct:free",
    "openrouter:meta-llama/llama-3.2-90b-vision-instruct",
    "openrouter:meta-llama/llama-3.3-70b-instruct",
    "openrouter:meta-llama/llama-3.3-70b-instruct:free",
    "openrouter:meta-llama/llama-4-maverick",
    "openrouter:meta-llama/llama-4-scout",
    "openrouter:meta-llama/llama-guard-2-8b",
    "openrouter:meta-llama/llama-guard-3-8b",
    "openrouter:meta-llama/llama-guard-4-12b",
    "openrouter:microsoft/mai-ds-r1",
    "openrouter:microsoft/mai-ds-r1:free",
    "openrouter:microsoft/phi-3-medium-128k-instruct",
    "openrouter:microsoft/phi-3-mini-128k-instruct",
    "openrouter:microsoft/phi-3.5-mini-128k-instruct",
    "openrouter:microsoft/phi-4",
    "openrouter:microsoft/phi-4-multimodal-instruct",
    "openrouter:microsoft/phi-4-reasoning-plus",
    "openrouter:microsoft/wizardlm-2-8x22b",
    "openrouter:minimax/minimax-01",
    "openrouter:minimax/minimax-m1",
    "openrouter:minimax/minimax-m2",
    "openrouter:mistralai/codestral-2501",
    "openrouter:mistralai/codestral-2508",
    "openrouter:mistralai/devstral-medium",
    "openrouter:mistralai/devstral-small",
    "openrouter:mistralai/devstral-small-2505",
    "openrouter:mistralai/magistral-medium-2506",
    "openrouter:mistralai/magistral-medium-2506:thinking",
    "openrouter:mistralai/magistral-small-2506",
    "openrouter:mistralai/ministral-3b",
    "openrouter:mistralai/ministral-8b",
    "openrouter:mistralai/mistral-7b-instruct",
    "openrouter:mistralai/mistral-7b-instruct-v0.1",
    "openrouter:mistralai/mistral-7b-instruct-v0.2",
    "openrouter:mistralai/mistral-7b-instruct-v0.3",
    "openrouter:mistralai/mistral-7b-instruct:free",
    "openrouter:mistralai/mistral-large",
    "openrouter:mistralai/mistral-large-2407",
    "openrouter:mistralai/mistral-large-2411",
    "openrouter:mistralai/mistral-medium-3",
    "openrouter:mistralai/mistral-medium-3.1",
    "openrouter:mistralai/mistral-nemo",
    "openrouter:mistralai/mistral-nemo:free",
    "openrouter:mistralai/mistral-saba",
    "openrouter:mistralai/mistral-small",
    "openrouter:mistralai/mistral-small-24b-instruct-2501",
    "openrouter:mistralai/mistral-small-24b-instruct-2501:free",
    "openrouter:mistralai/mistral-small-3.1-24b-instruct",
    "openrouter:mistralai/mistral-small-3.1-24b-instruct:free",
    "openrouter:mistralai/mistral-small-3.2-24b-instruct",
    "openrouter:mistralai/mistral-small-3.2-24b-instruct:free",
    "openrouter:mistralai/mistral-tiny",
    "openrouter:mistralai/mixtral-8x22b-instruct",
    "openrouter:mistralai/mixtral-8x7b-instruct",
    "openrouter:mistralai/pixtral-12b",
    "openrouter:mistralai/pixtral-large-2411",
    "openrouter:mistralai/voxtral-small-24b-2507",
    "openrouter:moonshotai/kimi-dev-72b",
    "openrouter:moonshotai/kimi-k2",
    "openrouter:moonshotai/kimi-k2-0905",
    "openrouter:moonshotai/kimi-k2-0905:exacto",
    "openrouter:moonshotai/kimi-k2-thinking",
    "openrouter:moonshotai/kimi-k2:free",
    "openrouter:moonshotai/kimi-linear-48b-a3b-instruct",
    "openrouter:morph/morph-v3-fast",
    "openrouter:morph/morph-v3-large",
    "openrouter:neversleep/llama-3.1-lumimaid-8b",
    "openrouter:neversleep/noromaid-20b",
    "openrouter:nousresearch/deephermes-3-mistral-24b-preview",
    "openrouter:nousresearch/hermes-2-pro-llama-3-8b",
    "openrouter:nousresearch/hermes-3-llama-3.1-405b",
    "openrouter:nousresearch/hermes-3-llama-3.1-405b:free",
    "openrouter:nousresearch/hermes-3-llama-3.1-70b",
    "openrouter:nousresearch/hermes-4-405b",
    "openrouter:nousresearch/hermes-4-70b",
    "openrouter:nvidia/llama-3.1-nemotron-70b-instruct",
    "openrouter:nvidia/llama-3.1-nemotron-ultra-253b-v1",
    "openrouter:nvidia/llama-3.3-nemotron-super-49b-v1.5",
    "openrouter:nvidia/nemotron-nano-12b-v2-vl",
    "openrouter:nvidia/nemotron-nano-12b-v2-vl:free",
    "openrouter:nvidia/nemotron-nano-9b-v2",
    "openrouter:nvidia/nemotron-nano-9b-v2:free",
    "openrouter:openai/chatgpt-4o-latest",
    "openrouter:openai/codex-mini",
    "openrouter:openai/gpt-3.5-turbo",
    "openrouter:openai/gpt-3.5-turbo-0613",
    "openrouter:openai/gpt-3.5-turbo-16k",
    "openrouter:openai/gpt-3.5-turbo-instruct",
    "openrouter:openai/gpt-4",
    "openrouter:openai/gpt-4-0314",
    "openrouter:openai/gpt-4-1106-preview",
    "openrouter:openai/gpt-4-turbo",
    "openrouter:openai/gpt-4-turbo-preview",
    "openrouter:openai/gpt-4.1",
    "openrouter:openai/gpt-4.1-mini",
    "openrouter:openai/gpt-4.1-nano",
    "openrouter:openai/gpt-4o",
    "openrouter:openai/gpt-4o-2024-05-13",
    "openrouter:openai/gpt-4o-2024-08-06",
    "openrouter:openai/gpt-4o-2024-11-20",
    "openrouter:openai/gpt-4o-audio-preview",
    "openrouter:openai/gpt-4o-mini",
    "openrouter:openai/gpt-4o-mini-2024-07-18",
    "openrouter:openai/gpt-4o-mini-search-preview",
    "openrouter:openai/gpt-4o-search-preview",
    "openrouter:openai/gpt-4o:extended",
    "openrouter:openai/gpt-5",
    "openrouter:openai/gpt-5-chat",
    "openrouter:openai/gpt-5-codex",
    "openrouter:openai/gpt-5-image",
    "openrouter:openai/gpt-5-image-mini",
    "openrouter:openai/gpt-5-mini",
    "openrouter:openai/gpt-5-nano",
    "openrouter:openai/gpt-5-pro",
    "openrouter:openai/gpt-5.1",
    "openrouter:openai/gpt-5.1-chat",
    "openrouter:openai/gpt-5.1-codex",
    "openrouter:openai/gpt-5.1-codex-mini",
    "openrouter:openai/gpt-oss-120b",
    "openrouter:openai/gpt-oss-120b:exacto",
    "openrouter:openai/gpt-oss-20b",
    "openrouter:openai/gpt-oss-20b:free",
    "openrouter:openai/gpt-oss-safeguard-20b",
    "openrouter:openai/o1",
    "openrouter:openai/o1-pro",
    "openrouter:openai/o3",
    "openrouter:openai/o3-deep-research",
    "openrouter:openai/o3-mini",
    "openrouter:openai/o3-mini-high",
    "openrouter:openai/o3-pro",
    "openrouter:openai/o4-mini",
    "openrouter:openai/o4-mini-deep-research",
    "openrouter:openai/o4-mini-high",
    "openrouter:opengvlab/internvl3-78b",
    "openrouter:openrouter/auto",
    "openrouter:openrouter/sherlock-dash-alpha",
    "openrouter:openrouter/sherlock-think-alpha",
    "openrouter:perplexity/sonar",
    "openrouter:perplexity/sonar-deep-research",
    "openrouter:perplexity/sonar-pro",
    "openrouter:perplexity/sonar-pro-search",
    "openrouter:perplexity/sonar-reasoning",
    "openrouter:perplexity/sonar-reasoning-pro",
    "openrouter:qwen/qwen-2.5-72b-instruct",
    "openrouter:qwen/qwen-2.5-72b-instruct:free",
    "openrouter:qwen/qwen-2.5-7b-instruct",
    "openrouter:qwen/qwen-2.5-coder-32b-instruct",
    "openrouter:qwen/qwen-2.5-coder-32b-instruct:free",
    "openrouter:qwen/qwen-2.5-vl-7b-instruct",
    "openrouter:qwen/qwen-max",
    "openrouter:qwen/qwen-plus",
    "openrouter:qwen/qwen-plus-2025-07-28",
    "openrouter:qwen/qwen-plus-2025-07-28:thinking",
    "openrouter:qwen/qwen-turbo",
    "openrouter:qwen/qwen-vl-max",
    "openrouter:qwen/qwen-vl-plus",
    "openrouter:qwen/qwen2.5-coder-7b-instruct",
    "openrouter:qwen/qwen2.5-vl-32b-instruct",
    "openrouter:qwen/qwen2.5-vl-32b-instruct:free",
    "openrouter:qwen/qwen2.5-vl-72b-instruct",
    "openrouter:qwen/qwen3-14b",
    "openrouter:qwen/qwen3-14b:free",
    "openrouter:qwen/qwen3-235b-a22b",
    "openrouter:qwen/qwen3-235b-a22b-2507",
    "openrouter:qwen/qwen3-235b-a22b-thinking-2507",
    "openrouter:qwen/qwen3-235b-a22b:free",
    "openrouter:qwen/qwen3-30b-a3b",
    "openrouter:qwen/qwen3-30b-a3b-instruct-2507",
    "openrouter:qwen/qwen3-30b-a3b-thinking-2507",
    "openrouter:qwen/qwen3-30b-a3b:free",
    "openrouter:qwen/qwen3-32b",
    "openrouter:qwen/qwen3-4b:free",
    "openrouter:qwen/qwen3-8b",
    "openrouter:qwen/qwen3-coder",
    "openrouter:qwen/qwen3-coder-30b-a3b-instruct",
    "openrouter:qwen/qwen3-coder-flash",
    "openrouter:qwen/qwen3-coder-plus",
    "openrouter:qwen/qwen3-coder:exacto",
    "openrouter:qwen/qwen3-coder:free",
    "openrouter:qwen/qwen3-max",
    "openrouter:qwen/qwen3-next-80b-a3b-instruct",
    "openrouter:qwen/qwen3-next-80b-a3b-thinking",
    "openrouter:qwen/qwen3-vl-235b-a22b-instruct",
    "openrouter:qwen/qwen3-vl-235b-a22b-thinking",
    "openrouter:qwen/qwen3-vl-30b-a3b-instruct",
    "openrouter:qwen/qwen3-vl-30b-a3b-thinking",
    "openrouter:qwen/qwen3-vl-8b-instruct",
    "openrouter:qwen/qwen3-vl-8b-thinking",
    "openrouter:qwen/qwq-32b",
    "openrouter:raifle/sorcererlm-8x22b",
    "openrouter:relace/relace-apply-3",
    "openrouter:sao10k/l3-euryale-70b",
    "openrouter:sao10k/l3-lunaris-8b",
    "openrouter:sao10k/l3.1-70b-hanami-x1",
    "openrouter:sao10k/l3.1-euryale-70b",
    "openrouter:sao10k/l3.3-euryale-70b",
    "openrouter:stepfun-ai/step3",
    "openrouter:switchpoint/router",
    "openrouter:tencent/hunyuan-a13b-instruct",
    "openrouter:thedrummer/anubis-70b-v1.1",
    "openrouter:thedrummer/cydonia-24b-v4.1",
    "openrouter:thedrummer/rocinante-12b",
    "openrouter:thedrummer/skyfall-36b-v2",
    "openrouter:thedrummer/unslopnemo-12b",
    "openrouter:thudm/glm-4.1v-9b-thinking",
    "openrouter:tngtech/deepseek-r1t-chimera",
    "openrouter:tngtech/deepseek-r1t-chimera:free",
    "openrouter:tngtech/deepseek-r1t2-chimera",
    "openrouter:tngtech/deepseek-r1t2-chimera:free",
    "openrouter:undi95/remm-slerp-l2-13b",
    "openrouter:x-ai/grok-3",
    "openrouter:x-ai/grok-3-beta",
    "openrouter:x-ai/grok-3-mini",
    "openrouter:x-ai/grok-3-mini-beta",
    "openrouter:x-ai/grok-4",
    "openrouter:x-ai/grok-4-fast",
    "openrouter:x-ai/grok-code-fast-1",
    "openrouter:z-ai/glm-4-32b",
    "openrouter:z-ai/glm-4.5",
    "openrouter:z-ai/glm-4.5-air",
    "openrouter:z-ai/glm-4.5-air:free",
    "openrouter:z-ai/glm-4.5v",
    "openrouter:z-ai/glm-4.6",
    "openrouter:z-ai/glm-4.6:exacto",
]

__all__ = ["OpenrouterModels"]
