"""Generated model names for gemini provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 55
"""

from __future__ import annotations

from typing import Literal


GeminiModels = Literal[
    "gemini:aqa",
    "gemini:gemini-2.0-flash",
    "gemini:gemini-2.0-flash-001",
    "gemini:gemini-2.0-flash-exp",
    "gemini:gemini-2.0-flash-lite",
    "gemini:gemini-2.0-flash-lite-001",
    "gemini:gemini-2.0-flash-lite-preview",
    "gemini:gemini-2.0-flash-lite-preview-02-05",
    "gemini:gemini-2.0-flash-live-001",
    "gemini:gemini-2.0-flash-thinking-exp",
    "gemini:gemini-2.0-flash-thinking-exp-01-21",
    "gemini:gemini-2.0-flash-thinking-exp-1219",
    "gemini:gemini-2.0-pro-exp",
    "gemini:gemini-2.0-pro-exp-02-05",
    "gemini:gemini-2.5-computer-use-preview-10-2025",
    "gemini:gemini-2.5-flash",
    "gemini:gemini-2.5-flash-image",
    "gemini:gemini-2.5-flash-image-preview",
    "gemini:gemini-2.5-flash-lite",
    "gemini:gemini-2.5-flash-lite-preview-06-17",
    "gemini:gemini-2.5-flash-lite-preview-09-2025",
    "gemini:gemini-2.5-flash-live-preview",
    "gemini:gemini-2.5-flash-native-audio-latest",
    "gemini:gemini-2.5-flash-native-audio-preview-09-2025",
    "gemini:gemini-2.5-flash-preview-05-20",
    "gemini:gemini-2.5-flash-preview-09-2025",
    "gemini:gemini-2.5-flash-preview-tts",
    "gemini:gemini-2.5-pro",
    "gemini:gemini-2.5-pro-preview-03-25",
    "gemini:gemini-2.5-pro-preview-05-06",
    "gemini:gemini-2.5-pro-preview-06-05",
    "gemini:gemini-2.5-pro-preview-tts",
    "gemini:gemini-exp-1206",
    "gemini:gemini-flash-latest",
    "gemini:gemini-flash-lite-latest",
    "gemini:gemini-live-2.5-flash-preview",
    "gemini:gemini-pro-latest",
    "gemini:gemini-robotics-er-1.5-preview",
    "gemini:gemma-3-12b-it",
    "gemini:gemma-3-1b-it",
    "gemini:gemma-3-27b-it",
    "gemini:gemma-3-4b-it",
    "gemini:gemma-3n-e2b-it",
    "gemini:gemma-3n-e4b-it",
    "gemini:imagen-4.0-fast-generate-001",
    "gemini:imagen-4.0-generate-001",
    "gemini:imagen-4.0-generate-preview-06-06",
    "gemini:imagen-4.0-ultra-generate-001",
    "gemini:imagen-4.0-ultra-generate-preview-06-06",
    "gemini:learnlm-2.0-flash-experimental",
    "gemini:veo-2.0-generate-001",
    "gemini:veo-3.0-fast-generate-001",
    "gemini:veo-3.0-generate-001",
    "gemini:veo-3.1-fast-generate-preview",
    "gemini:veo-3.1-generate-preview",
]

__all__ = ["GeminiModels"]
