"""Generated model names for copilot provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 5
"""

from __future__ import annotations

from typing import Literal


CopilotModels = Literal[
    "copilot:claude-haiku-4.5",
    "copilot:gpt-4.1",
    "copilot:gpt-4o",
    "copilot:gpt-5-mini",
    "copilot:oswe-vscode-prime",
]

__all__ = ["CopilotModels"]
