"""Generated model names for comet provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 564
"""

from __future__ import annotations

from typing import Literal


CometModels = Literal[
    "comet:DeepSeek-V3.2-Exp-nothinking",
    "comet:DeepSeek-V3.2-Exp-thinking",
    "comet:Hunyuan3D-2",
    "comet:Qwen2.5-72B-Instruct-128K",
    "comet:SparkDesk-v1.1",
    "comet:SparkDesk-v2.1",
    "comet:SparkDesk-v3.1",
    "comet:abab5.5-chat",
    "comet:abab5.5s-chat",
    "comet:abab6-chat",
    "comet:abab6.5g-chat",
    "comet:abab6.5s-chat",
    "comet:abab6.5t-chat",
    "comet:abab7-chat-preview",
    "comet:black-forest-labs/flux-1.1-pro",
    "comet:black-forest-labs/flux-1.1-pro-ultra",
    "comet:black-forest-labs/flux-dev",
    "comet:black-forest-labs/flux-kontext-max",
    "comet:black-forest-labs/flux-kontext-pro",
    "comet:black-forest-labs/flux-pro",
    "comet:black-forest-labs/flux-schnell",
    "comet:bria_image_edit_enhance",
    "comet:bria_image_edit_erase",
    "comet:bria_image_edit_expand",
    "comet:bria_image_edit_gen_fill",
    "comet:bria_image_edit_increase_resolution",
    "comet:bria_image_edit_replace_background",
    "comet:bria_text_to_image",
    "comet:bria_text_to_vector",
    "comet:bytedance-seedEdit-3.0-i2i",
    "comet:bytedance-seedance-1-0-lite",
    "comet:bytedance-seedance-1-0-lite-i2v-250428",
    "comet:bytedance-seedance-1-0-lite-t2v-250428",
    "comet:bytedance-seedance-1-0-pro",
    "comet:bytedance-seedream-3.0-t2i",
    "comet:bytedance-seedream-4-0-250828",
    "comet:chatgpt-4o-latest",
    "comet:claude-3-5-haiku-20241022",
    "comet:claude-3-5-haiku-latest",
    "comet:claude-3-5-sonnet-20240620",
    "comet:claude-3-5-sonnet-20241022",
    "comet:claude-3-5-sonnet-all",
    "comet:claude-3-5-sonnet-latest",
    "comet:claude-3-7-sonnet-20250219",
    "comet:claude-3-7-sonnet-20250219-thinking",
    "comet:claude-3-7-sonnet-latest",
    "comet:claude-3-7-sonnet-thinking",
    "comet:claude-3-haiku-20240307",
    "comet:claude-3-opus-20240229",
    "comet:claude-3-opus-latest",
    "comet:claude-haiku-4-5-20251001",
    "comet:claude-opus-4-1-20250805",
    "comet:claude-opus-4-1-20250805-thinking",
    "comet:claude-opus-4-20250514",
    "comet:claude-opus-4-20250514-thinking",
    "comet:claude-sonnet-4-20250514",
    "comet:claude-sonnet-4-20250514-thinking",
    "comet:claude-sonnet-4-5",
    "comet:claude-sonnet-4-5-20250929",
    "comet:claude-sonnet-4-5-20250929-thinking",
    "comet:codex-mini-latest",
    "comet:cometapi-3-5-sonnet",
    "comet:cometapi-3-7-sonnet",
    "comet:cometapi-3-7-sonnet-thinking",
    "comet:cometapi-haiku-4-5-20251001",
    "comet:cometapi-opus-4-1-20250805",
    "comet:cometapi-opus-4-1-20250805-thinking",
    "comet:cometapi-opus-4-20250514",
    "comet:cometapi-opus-4-20250514-thinking",
    "comet:cometapi-sonnet-4-20250514",
    "comet:cometapi-sonnet-4-20250514-thinking",
    "comet:cometapi-sonnet-4-5",
    "comet:cometapi-sonnet-4-5-20250929",
    "comet:cometapi-sonnet-4-5-20250929-thinking",
    "comet:dall-e-2",
    "comet:dall-e-3",
    "comet:deepseek-ai/DeepSeek-V3",
    "comet:deepseek-ai/deepseek-r1",
    "comet:deepseek-chat",
    "comet:deepseek-ocr",
    "comet:deepseek-r1",
    "comet:deepseek-r1-0528",
    "comet:deepseek-r1t2-chimera",
    "comet:deepseek-reasoner",
    "comet:deepseek-v3",
    "comet:deepseek-v3-1-250821",
    "comet:deepseek-v3-250324",
    "comet:deepseek-v3.1",
    "comet:deepseek-v3.1-think-250821",
    "comet:deepseek-v3.2-exp",
    "comet:doubao-1-5-pro-256k",
    "comet:doubao-1-5-pro-256k-250115",
    "comet:doubao-1-5-pro-32k",
    "comet:doubao-1-5-pro-32k-250115",
    "comet:doubao-1-5-thinking-pro-250415",
    "comet:doubao-1-5-thinking-vision-pro-250428",
    "comet:doubao-1-5-vision-pro-32k",
    "comet:doubao-1.5-lite-32k",
    "comet:doubao-1.5-pro-256k",
    "comet:doubao-1.5-pro-32k",
    "comet:doubao-1.5-pro-32k-250115",
    "comet:doubao-1.5-thinking-pro",
    "comet:doubao-1.5-vision-pro",
    "comet:doubao-1.5-vision-pro-250328",
    "comet:doubao-1.5-vision-pro-32k",
    "comet:doubao-1.5-vision-pro-32k-250115",
    "comet:doubao-lite-128k",
    "comet:doubao-lite-32k",
    "comet:doubao-lite-32k-240828",
    "comet:doubao-lite-4k",
    "comet:doubao-pro-128k",
    "comet:doubao-pro-256k",
    "comet:doubao-pro-32k",
    "comet:doubao-pro-32k-241215",
    "comet:doubao-pro-4k",
    "comet:doubao-seed-1-6-250615",
    "comet:doubao-seed-1-6-flash-250615",
    "comet:doubao-seed-1-6-thinking-250715",
    "comet:doubao-seedance-1-0-lite-i2v-250428",
    "comet:doubao-seedance-1-0-lite-t2v-250428",
    "comet:doubao-seedance-1-0-pro-250528",
    "comet:doubao-seedance-1.0-pro",
    "comet:doubao-seededit-3-0-i2i-250628",
    "comet:doubao-seedream-3-0-t2i-250415",
    "comet:doubao-seedream-4-0-250828",
    "comet:doubao-vision-pro-32k",
    "comet:flux-1.1-pro",
    "comet:flux-dev",
    "comet:flux-finetune",
    "comet:flux-kontext-max",
    "comet:flux-kontext-pro",
    "comet:flux-pro",
    "comet:flux-pro-1.0-canny",
    "comet:flux-pro-1.0-canny-finetuned",
    "comet:flux-pro-1.0-depth",
    "comet:flux-pro-1.0-depth-finetuned",
    "comet:flux-pro-1.0-fill",
    "comet:flux-pro-1.0-fill-finetuned",
    "comet:flux-pro-1.1",
    "comet:flux-pro-1.1-ultra",
    "comet:flux-pro-1.1-ultra-finetuned",
    "comet:flux-pro-finetuned",
    "comet:gemini-2.0-flash",
    "comet:gemini-2.0-flash-exp",
    "comet:gemini-2.0-flash-exp-image-generation",
    "comet:gemini-2.0-flash-lite-preview-02-05",
    "comet:gemini-2.0-flash-thinking",
    "comet:gemini-2.0-flash-thinking-exp",
    "comet:gemini-2.0-flash-thinking-exp-01-21",
    "comet:gemini-2.0-flash-thinking-exp-0119",
    "comet:gemini-2.0-flash-thinking-exp-0129",
    "comet:gemini-2.0-flash-thinking-exp-1219",
    "comet:gemini-2.0-pro-exp",
    "comet:gemini-2.0-pro-exp-02-05",
    "comet:gemini-2.5-flash",
    "comet:gemini-2.5-flash-all",
    "comet:gemini-2.5-flash-deepsearch",
    "comet:gemini-2.5-flash-image",
    "comet:gemini-2.5-flash-image-preview",
    "comet:gemini-2.5-flash-lite",
    "comet:gemini-2.5-flash-lite-preview-06-17",
    "comet:gemini-2.5-flash-lite-preview-06-17-thinking",
    "comet:gemini-2.5-flash-lite-preview-09-2025",
    "comet:gemini-2.5-flash-lite-thinking",
    "comet:gemini-2.5-flash-preview-04-17",
    "comet:gemini-2.5-flash-preview-05-20",
    "comet:gemini-2.5-flash-preview-05-20-thinking",
    "comet:gemini-2.5-flash-preview-09-2025",
    "comet:gemini-2.5-flash-thinking",
    "comet:gemini-2.5-pro",
    "comet:gemini-2.5-pro-all",
    "comet:gemini-2.5-pro-deepsearch",
    "comet:gemini-2.5-pro-exp-03-25",
    "comet:gemini-2.5-pro-preview-03-25",
    "comet:gemini-2.5-pro-preview-05-06",
    "comet:gemini-2.5-pro-preview-06-05",
    "comet:gemini-2.5-pro-thinking",
    "comet:gemini-exp-1114",
    "comet:gemini-exp-1121",
    "comet:gemini-exp-1206",
    "comet:glm-3-turbo",
    "comet:glm-4",
    "comet:glm-4-0520",
    "comet:glm-4-air",
    "comet:glm-4-airx",
    "comet:glm-4-all",
    "comet:glm-4-flash",
    "comet:glm-4-plus",
    "comet:glm-4.5",
    "comet:glm-4.5-air",
    "comet:glm-4.5-airx",
    "comet:glm-4.5-flash",
    "comet:glm-4.5-x",
    "comet:glm-4.6",
    "comet:glm-4v",
    "comet:glm-4v-plus",
    "comet:gpt-3.5-turbo",
    "comet:gpt-3.5-turbo-0125",
    "comet:gpt-3.5-turbo-0301",
    "comet:gpt-3.5-turbo-0613",
    "comet:gpt-3.5-turbo-1106",
    "comet:gpt-3.5-turbo-16k",
    "comet:gpt-3.5-turbo-16k-0613",
    "comet:gpt-3.5-turbo-instruct",
    "comet:gpt-4",
    "comet:gpt-4-0125-preview",
    "comet:gpt-4-0314",
    "comet:gpt-4-0613",
    "comet:gpt-4-1106-preview",
    "comet:gpt-4-32k",
    "comet:gpt-4-32k-0314",
    "comet:gpt-4-32k-0613",
    "comet:gpt-4-all",
    "comet:gpt-4-gizmo-*",
    "comet:gpt-4-turbo",
    "comet:gpt-4-turbo-2024-04-09",
    "comet:gpt-4-turbo-preview",
    "comet:gpt-4-vision-preview",
    "comet:gpt-4.1",
    "comet:gpt-4.1-2025-04-14",
    "comet:gpt-4.1-mini",
    "comet:gpt-4.1-mini-2025-04-14",
    "comet:gpt-4.1-nano",
    "comet:gpt-4.1-nano-2025-04-14",
    "comet:gpt-4o",
    "comet:gpt-4o-2024-05-13",
    "comet:gpt-4o-2024-08-06",
    "comet:gpt-4o-2024-11-20",
    "comet:gpt-4o-all",
    "comet:gpt-4o-audio-preview",
    "comet:gpt-4o-audio-preview-2024-10-01",
    "comet:gpt-4o-audio-preview-2024-12-17",
    "comet:gpt-4o-audio-preview-2025-06-03",
    "comet:gpt-4o-image",
    "comet:gpt-4o-mini",
    "comet:gpt-4o-mini-2024-07-18",
    "comet:gpt-4o-mini-audio-preview",
    "comet:gpt-4o-mini-audio-preview-2024-12-17",
    "comet:gpt-4o-mini-realtime-preview",
    "comet:gpt-4o-mini-realtime-preview-2024-12-17",
    "comet:gpt-4o-mini-search-preview",
    "comet:gpt-4o-mini-search-preview-2025-03-11",
    "comet:gpt-4o-mini-transcribe",
    "comet:gpt-4o-mini-tts",
    "comet:gpt-4o-realtime-preview",
    "comet:gpt-4o-realtime-preview-2024-10-01",
    "comet:gpt-4o-realtime-preview-2024-12-17",
    "comet:gpt-4o-realtime-preview-2025-06-03",
    "comet:gpt-4o-search",
    "comet:gpt-4o-search-preview",
    "comet:gpt-4o-search-preview-2025-03-11",
    "comet:gpt-4o-transcribe",
    "comet:gpt-5",
    "comet:gpt-5-2025-08-07",
    "comet:gpt-5-all",
    "comet:gpt-5-chat-latest",
    "comet:gpt-5-codex",
    "comet:gpt-5-codex-high",
    "comet:gpt-5-codex-low",
    "comet:gpt-5-codex-medium",
    "comet:gpt-5-high",
    "comet:gpt-5-low",
    "comet:gpt-5-medium",
    "comet:gpt-5-mini",
    "comet:gpt-5-mini-2025-08-07",
    "comet:gpt-5-minimal",
    "comet:gpt-5-nano",
    "comet:gpt-5-nano-2025-08-07",
    "comet:gpt-5-pro",
    "comet:gpt-5-pro-2025-10-06",
    "comet:gpt-5-thinking",
    "comet:gpt-5-thinking-all",
    "comet:gpt-5.1",
    "comet:gpt-5.1-chat-latest",
    "comet:gpt-5.1-codex",
    "comet:gpt-image-1",
    "comet:gpt-image-1-mini",
    "comet:gpt-oss-120b",
    "comet:gpt-oss-20b",
    "comet:grok-2",
    "comet:grok-2-1212",
    "comet:grok-2-vision-1212",
    "comet:grok-3",
    "comet:grok-3-beta",
    "comet:grok-3-deepersearch",
    "comet:grok-3-deepsearch",
    "comet:grok-3-fast",
    "comet:grok-3-fast-latest",
    "comet:grok-3-latest",
    "comet:grok-3-mini",
    "comet:grok-3-mini-fast",
    "comet:grok-3-mini-fast-latest",
    "comet:grok-3-mini-latest",
    "comet:grok-3-reasoner",
    "comet:grok-3-reasoning",
    "comet:grok-3-search",
    "comet:grok-4",
    "comet:grok-4-0709",
    "comet:grok-4-auto",
    "comet:grok-4-fast-non-reasoning",
    "comet:grok-4-fast-reasoning",
    "comet:grok-code-fast-1",
    "comet:hunyuan",
    "comet:hunyuan-a13b",
    "comet:hunyuan-code",
    "comet:hunyuan-functioncall",
    "comet:hunyuan-large",
    "comet:hunyuan-large-vision",
    "comet:hunyuan-lite",
    "comet:hunyuan-pro",
    "comet:hunyuan-role",
    "comet:hunyuan-standard",
    "comet:hunyuan-standard-256K",
    "comet:hunyuan-t1-20250321",
    "comet:hunyuan-t1-20250403",
    "comet:hunyuan-t1-20250521",
    "comet:hunyuan-t1-20250529",
    "comet:hunyuan-t1-20250711",
    "comet:hunyuan-t1-20250822",
    "comet:hunyuan-t1-latest",
    "comet:hunyuan-t1-vision",
    "comet:hunyuan-t1-vision-20250619",
    "comet:hunyuan-turbos-20250313",
    "comet:hunyuan-turbos-20250416",
    "comet:hunyuan-turbos-20250515",
    "comet:hunyuan-turbos-20250604",
    "comet:hunyuan-turbos-latest",
    "comet:hunyuan-turbos-longtext-128k-20250325",
    "comet:hunyuan-turbos-vision",
    "comet:hunyuan-turbos-vision-20250619",
    "comet:hunyuan-vision",
    "comet:ideogram-ai/ideogram-v2",
    "comet:ideogram-ai/ideogram-v2-turbo",
    "comet:ideogram-ai/ideogram-v2a",
    "comet:ideogram-ai/ideogram-v3-balanced",
    "comet:ideogram-ai/ideogram-v3-quality",
    "comet:ideogram-ai/ideogram-v3-turbo",
    "comet:kimi-k2-0711-preview",
    "comet:kimi-k2-0905-preview",
    "comet:kimi-k2-250905",
    "comet:kimi-k2-thinking",
    "comet:kimi-k2-thinking-turbo",
    "comet:kling_advanced_lip_sync",
    "comet:kling_audio_text_to_audio",
    "comet:kling_audio_video_to_audio",
    "comet:kling_avatar_image2video",
    "comet:kling_effects",
    "comet:kling_extend",
    "comet:kling_identify_face",
    "comet:kling_image",
    "comet:kling_image_expand",
    "comet:kling_image_recognize",
    "comet:kling_lip_sync",
    "comet:kling_multi_elements_add",
    "comet:kling_multi_elements_clear",
    "comet:kling_multi_elements_delete",
    "comet:kling_multi_elements_init",
    "comet:kling_multi_elements_preview",
    "comet:kling_multi_elements_submit",
    "comet:kling_multi_image2image",
    "comet:kling_tts",
    "comet:kling_video",
    "comet:kling_virtual_try_on",
    "comet:llama-4-maverick",
    "comet:llama-4-scout",
    "comet:luma-video",
    "comet:luma_extend",
    "comet:luma_fast_extend",
    "comet:luma_fast_nomark",
    "comet:luma_fast_video",
    "comet:luma_nomark",
    "comet:luma_relax_extend",
    "comet:luma_relax_nomark",
    "comet:luma_relax_video",
    "comet:luma_video",
    "comet:minimax-hailuo-02",
    "comet:minimax-m2",
    "comet:minimax_files_retrieve",
    "comet:minimax_minimax-hailuo-02",
    "comet:minimax_video-01",
    "comet:mj_fast_blend",
    "comet:mj_fast_custom_zoom",
    "comet:mj_fast_describe",
    "comet:mj_fast_edits",
    "comet:mj_fast_high_variation",
    "comet:mj_fast_imagine",
    "comet:mj_fast_inpaint",
    "comet:mj_fast_low_variation",
    "comet:mj_fast_modal",
    "comet:mj_fast_pan",
    "comet:mj_fast_pic_reader",
    "comet:mj_fast_prompt_analyzer",
    "comet:mj_fast_prompt_analyzer_extended",
    "comet:mj_fast_reroll",
    "comet:mj_fast_shorten",
    "comet:mj_fast_upload",
    "comet:mj_fast_upscale",
    "comet:mj_fast_upscale_creative",
    "comet:mj_fast_upscale_subtle",
    "comet:mj_fast_variation",
    "comet:mj_fast_video",
    "comet:mj_fast_zoom",
    "comet:mj_turbo_blend",
    "comet:mj_turbo_custom_zoom",
    "comet:mj_turbo_describe",
    "comet:mj_turbo_high_variation",
    "comet:mj_turbo_imagine",
    "comet:mj_turbo_inpaint",
    "comet:mj_turbo_low_variation",
    "comet:mj_turbo_modal",
    "comet:mj_turbo_pan",
    "comet:mj_turbo_pic_reader",
    "comet:mj_turbo_prompt_analyzer",
    "comet:mj_turbo_prompt_analyzer_extended",
    "comet:mj_turbo_reroll",
    "comet:mj_turbo_shorten",
    "comet:mj_turbo_upload",
    "comet:mj_turbo_upscale",
    "comet:mj_turbo_upscale_creative",
    "comet:mj_turbo_upscale_subtle",
    "comet:mj_turbo_variation",
    "comet:mj_turbo_zoom",
    "comet:moonshot-v1-128k",
    "comet:moonshot-v1-32k",
    "comet:moonshot-v1-8k",
    "comet:o1",
    "comet:o1-2024-12-17",
    "comet:o1-mini",
    "comet:o1-mini-2024-09-12",
    "comet:o1-preview",
    "comet:o1-preview-2024-09-12",
    "comet:o1-pro",
    "comet:o1-pro-2025-03-19",
    "comet:o1-pro-all",
    "comet:o3",
    "comet:o3-2025-04-16",
    "comet:o3-deep-research",
    "comet:o3-deep-research-2025-06-26",
    "comet:o3-mini",
    "comet:o3-mini-2025-01-31",
    "comet:o3-mini-2025-01-31-high",
    "comet:o3-mini-2025-01-31-low",
    "comet:o3-mini-2025-01-31-medium",
    "comet:o3-mini-all",
    "comet:o3-mini-high",
    "comet:o3-mini-high-2025-01-31",
    "comet:o3-mini-high-all",
    "comet:o3-mini-low",
    "comet:o3-mini-medium",
    "comet:o3-pro",
    "comet:o3-pro-2025-06-10",
    "comet:o4-mini",
    "comet:o4-mini-2025-04-16",
    "comet:o4-mini-deep-research",
    "comet:o4-mini-deep-research-2025-06-26",
    "comet:omni-moderation-2024-09-26",
    "comet:omni-moderation-latest",
    "comet:qwen-72b",
    "comet:qwen-image",
    "comet:qwen-image-edit",
    "comet:qwen-long",
    "comet:qwen-max",
    "comet:qwen-max-2025-01-25",
    "comet:qwen-max-latest",
    "comet:qwen-omni-turbo",
    "comet:qwen-plus",
    "comet:qwen-plus-latest",
    "comet:qwen-turbo",
    "comet:qwen-turbo-1101",
    "comet:qwen-turbo-2024-11-01",
    "comet:qwen-turbo-latest",
    "comet:qwen-vl-max",
    "comet:qwen-vl-max-0201",
    "comet:qwen-vl-max-0809",
    "comet:qwen-vl-max-latest",
    "comet:qwen-vl-ocr",
    "comet:qwen-vl-plus",
    "comet:qwen-vl-plus-latest",
    "comet:qwen/qwq-32b",
    "comet:qwen1.5-110b-chat",
    "comet:qwen1.5-14b-chat",
    "comet:qwen1.5-32b-chat",
    "comet:qwen1.5-7b-chat",
    "comet:qwen2-1.5b-instruct",
    "comet:qwen2-57b-a14b-instruct",
    "comet:qwen2-72b-instruct",
    "comet:qwen2-7b-instruct",
    "comet:qwen2-vl-72b-instruct",
    "comet:qwen2-vl-7b-instruct",
    "comet:qwen2.5-14b-instruct",
    "comet:qwen2.5-32b-instruct",
    "comet:qwen2.5-72b-instruct",
    "comet:qwen2.5-7b-instruct",
    "comet:qwen2.5-coder-32b-instruct",
    "comet:qwen2.5-coder-7b-instruct",
    "comet:qwen2.5-math-72b-instruct",
    "comet:qwen2.5-omni-7b",
    "comet:qwen2.5-vl-32b-instruct",
    "comet:qwen2.5-vl-72b",
    "comet:qwen2.5-vl-72b-instruct",
    "comet:qwen3-14b",
    "comet:qwen3-235b-a22b",
    "comet:qwen3-30b-a3b",
    "comet:qwen3-32b",
    "comet:qwen3-8b",
    "comet:qwen3-coder",
    "comet:qwen3-coder-480b-a35b-instruct",
    "comet:qwen3-coder-plus",
    "comet:qwen3-coder-plus-2025-07-22",
    "comet:qwen3-max-preview",
    "comet:qwq-32b",
    "comet:recraft-ai/recraft-v3",
    "comet:recraft-ai/recraft-v3-svg",
    "comet:recraft-api",
    "comet:recraftv3",
    "comet:runway_act_one",
    "comet:runway_video",
    "comet:runway_video2video",
    "comet:runwayml_character_performance",
    "comet:runwayml_control_character",
    "comet:runwayml_image_to_video",
    "comet:runwayml_text_to_image",
    "comet:runwayml_upscale_video",
    "comet:runwayml_video_to_video",
    "comet:sora-2",
    "comet:sora-2-all",
    "comet:sora-2-pro",
    "comet:sora-2-pro-all",
    "comet:stability-ai/sdxl",
    "comet:stability-ai/stable-diffusion",
    "comet:stability-ai/stable-diffusion-3",
    "comet:stability-ai/stable-diffusion-3.5-large",
    "comet:stability-ai/stable-diffusion-3.5-large-turbo",
    "comet:stability-ai/stable-diffusion-3.5-medium",
    "comet:stable-diffusion-v1-5-inpainting",
    "comet:suno_act_create_project",
    "comet:suno_act_midi",
    "comet:suno_act_mp4",
    "comet:suno_act_stems",
    "comet:suno_act_tags",
    "comet:suno_act_timing",
    "comet:suno_act_wav",
    "comet:suno_concat",
    "comet:suno_lyrics",
    "comet:suno_music",
    "comet:suno_persona_create",
    "comet:suno_render",
    "comet:suno_uploads",
    "comet:tts",
    "comet:tts-1",
    "comet:tts-1-1106",
    "comet:tts-1-hd",
    "comet:tts-1-hd-1106",
    "comet:tts-hd",
    "comet:veo3",
    "comet:veo3-fast",
    "comet:veo3-fast-frames",
    "comet:veo3-frames",
    "comet:veo3-pro",
    "comet:veo3-pro-frames",
    "comet:veo3.1",
    "comet:veo3.1-pro",
    "comet:whisper-1",
    "comet:yi-vl-plus",
]

__all__ = ["CometModels"]
