"""Generated model names for openai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 29
"""

from __future__ import annotations

from typing import Literal


OpenaiModels = Literal[
    "openai:codex-mini-latest",
    "openai:gpt-3.5-turbo",
    "openai:gpt-4",
    "openai:gpt-4-turbo",
    "openai:gpt-4.1",
    "openai:gpt-4.1-mini",
    "openai:gpt-4.1-nano",
    "openai:gpt-4o",
    "openai:gpt-4o-2024-05-13",
    "openai:gpt-4o-2024-08-06",
    "openai:gpt-4o-2024-11-20",
    "openai:gpt-4o-mini",
    "openai:gpt-5",
    "openai:gpt-5-chat-latest",
    "openai:gpt-5-codex",
    "openai:gpt-5-mini",
    "openai:gpt-5-nano",
    "openai:gpt-5-pro",
    "openai:gpt-5.1",
    "openai:o1",
    "openai:o1-mini",
    "openai:o1-preview",
    "openai:o1-pro",
    "openai:o3",
    "openai:o3-deep-research",
    "openai:o3-mini",
    "openai:o3-pro",
    "openai:o4-mini",
    "openai:o4-mini-deep-research",
]

__all__ = ["OpenaiModels"]
