"""Generated model names for zai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 5
"""

from __future__ import annotations

from typing import Literal


ZaiModels = Literal[
    "zai:glm-4.5",
    "zai:glm-4.5-air",
    "zai:glm-4.5-flash",
    "zai:glm-4.5v",
    "zai:glm-4.6",
]

__all__ = ["ZaiModels"]
