"""Generated model names for mistral provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 43
"""

from __future__ import annotations

from typing import Literal


MistralModels = Literal[
    "mistral:codestral-2508",
    "mistral:codestral-latest",
    "mistral:devstral-medium-2507",
    "mistral:devstral-medium-latest",
    "mistral:devstral-small-2507",
    "mistral:devstral-small-latest",
    "mistral:magistral-medium-2509",
    "mistral:magistral-medium-latest",
    "mistral:magistral-small-2509",
    "mistral:magistral-small-latest",
    "mistral:ministral-3b-2410",
    "mistral:ministral-3b-latest",
    "mistral:ministral-8b-2410",
    "mistral:ministral-8b-latest",
    "mistral:mistral-large-2411",
    "mistral:mistral-large-latest",
    "mistral:mistral-large-pixtral-2411",
    "mistral:mistral-medium",
    "mistral:mistral-medium-2505",
    "mistral:mistral-medium-2508",
    "mistral:mistral-medium-latest",
    "mistral:mistral-ocr-2505",
    "mistral:mistral-ocr-latest",
    "mistral:mistral-small-2506",
    "mistral:mistral-small-latest",
    "mistral:mistral-tiny",
    "mistral:mistral-tiny-2312",
    "mistral:mistral-tiny-2407",
    "mistral:mistral-tiny-latest",
    "mistral:mistral-vibe-cli-latest",
    "mistral:open-mistral-7b",
    "mistral:open-mistral-nemo",
    "mistral:open-mistral-nemo-2407",
    "mistral:pixtral-12b",
    "mistral:pixtral-12b-2409",
    "mistral:pixtral-12b-latest",
    "mistral:pixtral-large-2411",
    "mistral:pixtral-large-latest",
    "mistral:voxtral-mini-2507",
    "mistral:voxtral-mini-latest",
    "mistral:voxtral-mini-transcribe-2507",
    "mistral:voxtral-small-2507",
    "mistral:voxtral-small-latest",
]

__all__ = ["MistralModels"]
